/*@import url("https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css");*/

/*
  expands the clickable area of the main link
  to fill the parent container, because it's the nearest
  ancestor with "position:relative"
*/
.list-group-item-action .main-link::before {
    content: '';
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    margin-right: 30mm;
}

.right-margin {
    margin-right: 5mm;
}

.left-margin {
    margin-left: 5mm;
}


#content {
    height: 100%
}

.width100 {
    width: 100%
}

.hide{
  display: none
}

.myclose {
    padding: 0;
    background-color: transparent;
    border: 0;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
}

p.monospace {
    font-family: "Courier New", monospace;
}

th.monospace {
    font-family: "Courier New", monospace;
}

.mycard-header:after {
    font-family: "Courier New", monospace;
    content: "-";
    float: right;
}

.mycard-header.collapsed:after {
    /* symbol for "collapsed" panels */
    font-family: "Courier New", monospace;
    content: "+";
}

.cursor-pointer {
    cursor: pointer;
}

.voter-table {
    max-height: 400px;
    overflow-y: auto;
}

.voter-table > .list-group-item {
    border-width: 0 0 1px;
}

.hamburger {
    width: 20px;
    height: 2px;
    box-shadow: inset 0 0 0 32px, 0 -6px, 0 6px;
    margin: 10px 3px;
    box-sizing: border-box;
    display: inline-block;
    vertical-align: middle;
    position: relative;
    font-style: normal;
    color: currentColor;
    text-align: left;
    text-indent: -9999px;
    direction: ltr;
}

.hamburger:before {
    content: "";
    pointer-events: none;
}

.hamburger:after {
    content: "";
    pointer-events: none;
}
