# Generated by Django 3.1.4 on 2020-12-08 21:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('vote', '0024_auto_20201116_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='session',
            name='spectator_token',
            field=models.UUIDField(blank=True, null=True, unique=True),
        ),
    ]
