# Generated by Django 3.0.5 on 2020-05-29 19:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0002_auto_20200529_2104'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='application',
            name='room',
        ),
        migrations.AlterField(
            model_name='application',
            name='email',
            field=models.EmailField(blank=True, max_length=254, null=True),
        ),
    ]
