# Generated by Django 3.0.5 on 2020-05-31 22:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0010_auto_20200601_0020'),
    ]

    operations = [
        migrations.AddField(
            model_name='voter',
            name='logged_in',
            field=models.BooleanField(default=False),
        ),
    ]
