# Generated by Django 3.1.2 on 2020-10-21 20:04

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('vote', '0016_voter_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='election',
            name='send_emails_on_start',
            field=models.BooleanField(default=False),
        ),
    ]
