# Generated by Django 3.1.2 on 2020-11-04 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0021_auto_20201103_1923'),
    ]

    operations = [
        migrations.AlterField(
            model_name='election',
            name='remind_text',
            field=models.TextField(blank=True, max_length=8000, null=True),
        ),
        migrations.AlterField(
            model_name='session',
            name='invite_text',
            field=models.TextField(blank=True, max_length=8000, null=True),
        ),
    ]
