{% load static %}
<div class="image-input form-group">
    {% if widget.is_initial %}
    <div class="img-wrapper">
        <img src="{{ widget.value.url }}" class="applicant-picture" alt="applicant-picture" />
    </div>
    {% if not widget.required %}
        <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}">
        <label for="{{ widget.checkbox_id }}">Delete</label>
    {% endif %}<br>
    {% else %}
    <div class="img-wrapper">
        <img src="{% static 'img/blank_avatar.png' %}" class="applicant-picture" alt="applicant-picture" />
    </div>
    {% endif %}
    <input type="{{ widget.type }}" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}><br>
    <small class="text-muted">(about 100x100 px)</small>
</div>
