{% extends 'management/base.html' %}
{% load static %}
{% load crispy_forms_filters %}

{% block content %}
  <div class="row justify-content-center">
    <div class="col-12">
      <div class="card shadow">
        <div class="card-body">
          <h4>Import Voters from CSV File</h4>
          <span>This page can be used to add voters via a CSV file. The file needs to have two columns email and name.
            The content of an exemplary CSV file is shown below:<br><br>
            <p class="monospace">email,name<br>erika.musterfrau@stusta.de,Erika Musterfrau<br>
              max.mustermann@stusta.de,Max Mustermann</p>
          </span>
          <hr>
          <form class="user" action="{% url 'management:import_csv' session.pk %}" method="post"
                enctype="multipart/form-data">
            {% csrf_token %}
            {{ form|crispy }}
            <button type="submit" id="id_btn_start" class="btn btn-success">Submit</button>
          </form>
        </div>
      </div>
    </div>
  </div>
{% endblock %}
