{% extends 'vote/base.html' %}

{% block content %}
  <div class="row justify-content-center">
    <div class="col-12 text-center">
      <span class="display-1 d-block">429</span>
      <div class="mb-4 lead">Too many attempts! Try again in 1 hour.</div>
    </div>
  </div>
{% endblock %}
