# Generated by Django 3.0.5 on 2020-05-31 22:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0009_remove_voter_remind_me'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='voter',
            name='first_name',
        ),
        migrations.RemoveField(
            model_name='voter',
            name='last_name',
        ),
    ]
