# Generated by Django 3.1.2 on 2020-11-11 13:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0022_auto_20201104_1438'),
    ]

    operations = [
        migrations.AddField(
            model_name='election',
            name='disable_abstention',
            field=models.BooleanField(default=False),
        ),
    ]
