{% extends 'management/base.html' %}
{% load static %}
{% load crispy_forms_filters %}

{% block content %}
  <div class="row justify-content-center">
    <div class="col-12">
      <div class="card shadow">
        <div class="card-body">
          <h4>Add Voters</h4>
          <span>Enter <b>one email address per line</b> in the field below.<br>
            These emails will receive an access code for this session after clicking "Submit".
          </span>
          <hr>
          <form class="user" action="{% url 'management:add_voters' session.pk %}" method="post">
            {% csrf_token %}
            {{ form|crispy }}
            <button type="submit" id="id_btn_start" class="btn btn-success">Submit</button>
          </form>
        </div>
      </div>
    </div>
  </div>
{% endblock %}
