#content {
    height: 100%;
}

@media (min-width: 768px) {
    .container, .container-md, .container-sm {
        max-width: 720px !important;
    }
}

.navbar-brand img {
    height: 1.6em;
    margin-top: -0.3em;
}

@media (max-width: 420px) {
    .navbar-brand img {
        height: 1.2em;
        margin-top: -0.2em;
    }
}

.card-body :last-child {
    margin-bottom: 0;
}

.card-dual .card-body:first-of-type {
    padding-bottom: 0.75rem;
}

.card-dual .card-body:last-of-type {
    border-top: 1px solid rgba(0,0,0,.125);
    padding-top: 0.75rem;
}

table.vote-list {
    margin: 0;
    margin-top: 1.75rem;
}

table.vote-list th {
    position: sticky;
    top: 0;
    z-index: 100;
}

table.vote-list th.choice {
    width: 15%;
}

table.vote-list th:nth-child(2),
table.vote-list td:nth-child(2) {
    border-left: 1px solid #dee2e6;
}

table.vote-list th:nth-child(3),
table.vote-list td:nth-child(3) {
    border-right: 1px solid #dee2e6;
}

table.vote-list td:last-child {
    background: #e9ecef;
}

table.vote-list tfoot td {
    border-left: none !important;
    border-right: none !important;
    background: none !important;
    color: #495057;
    font-size: 0.8em;
}

table.vote-list label {
    width: 100%;
    height: 100%;
    min-height: 50px;
}

table.vote-list td.applicant {
    padding-left: 0;
    max-width: 430px;
}

table.vote-list .applicant .card-body {
    padding: 1vw;
    padding-top: 0;
    padding-bottom: 0;
}

.applicant-picture,
.vote-list .applicant .col-3 {
    width: auto;
    height: auto;
    min-width: 50px;
    max-width: 100px;
    max-height: 100px;
}

.vote-list .applicant-picture {
    float: right;
    margin-left: 7px;
    margin-bottom: 7px;
    border-radius: 4px;
}

.vote-list .applicant h6 {
    font-size: 1.1rem;
    margin-bottom: .4rem;
}

.vote-list .applicant p {
    font-size: 0.8em;
}

.image-input .img-wrapper {
    height: 100px;
    float: left;
}

.image-input .applicant-picture {
    margin-right: 1rem;
}


.myclose {
    padding: 0;
    background-color: transparent;
    border: 0;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
}

.pic {
    width: 100%;
}

.just {
    text-align: justify;
}
