/* ----------------------------------------------------------------------------- 

  jQuery DateTimePicker - Responsive flat design jQuery DateTime Picker plugin for Web & Mobile
  Version 0.1.39
  Copyright (c)2014-2019 Lajpat Shah
  Contributors : https://github.com/nehakadam/DateTimePicker/contributors
  Repository : https://github.com/nehakadam/DateTimePicker
  Documentation : https://nehakadam.github.io/DateTimePicker

 ----------------------------------------------------------------------------- */

.dtpicker-overlay {
    z-index: 2000;
    display: none;
    min-width: 300px;

    background: rgba(0, 0, 0, 0.2);
    font-size: 12px;

    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}

.dtpicker-mobile {
    position: fixed;
    top: 0;
    left: 0;

    width: 100%;
    height: 100%;
}

.dtpicker-overlay * {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -ms-box-sizing: border-box;

    -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}

.dtpicker-bg {
    width: 100%;
    height: 100%;

    font-family: Arial;
}

.dtpicker-cont {
    border: 1px solid #ECF0F1;
}

.dtpicker-mobile .dtpicker-cont {
    position: relative;
    top: 50%;

    -webkit-transform: translateY(-50%);
    -moz-transform: translateY(-50%);
    -o-transform: translateY(-50%);
    -ms-transform: translateY(-50%);
    transform: translateY(-50%);

    border: none;
}

.dtpicker-content {
    margin: 0 auto;
    padding: 1em 0;

    max-width: 500px;

    background: #fff;
}

.dtpicker-mobile .dtpicker-content {
    width: 97%;
}

.dtpicker-subcontent {
    position: relative;
}

.dtpicker-header {
    margin: 0.2em 1em;
}

.dtpicker-header .dtpicker-title {
    color: #2980B9;
    text-align: center;
    font-size: 1.1em;
}

.dtpicker-header .dtpicker-close {
    position: absolute;
    top: -0.7em;
    right: 0.3em;

    padding: 0.5em 0.5em 1em 1em;

    color: #FF3B30;
    font-size: 1.5em;

    cursor: pointer;
}

.dtpicker-header .dtpicker-close:hover {
    color: #FF3B30;
}

.dtpicker-header .dtpicker-value {
    padding: 0.8em 0.2em 0.2em 0.2em;
    color: #FF3B30;
    text-align: center;

    font-size: 1.4em;
}

.dtpicker-components {
    overflow: hidden;
    margin: 1em 1em;

    font-size: 1.3em;
}

.dtpicker-components * {
    margin: 0;
    padding: 0;
}

.dtpicker-components .dtpicker-compOutline {
    display: inline-block;
    float: left;
}

.dtpicker-comp2 {
    width: 50%;
}

.dtpicker-comp3 {
    width: 33.3%;
}

.dtpicker-comp4 {
    width: 25%;
}

.dtpicker-comp5 {
    width: 20%;
}

.dtpicker-comp6 {
    width: 16.66%;
}

.dtpicker-comp7 {
    width: 14.285%;
}

.dtpicker-components .dtpicker-comp {
    margin: 2%;
    text-align: center;
}

.dtpicker-components .dtpicker-comp > * {
    display: block;
    height: 30px;

    color: #2980B9;

    text-align: center;
    line-height: 30px;
}

.dtpicker-components .dtpicker-comp > *:hover {
    color: #2980B9;
}

.dtpicker-components .dtpicker-compButtonEnable {
    opacity: 1;
}

.dtpicker-components .dtpicker-compButtonDisable {
    opacity: 0.5;
}

.dtpicker-components .dtpicker-compButton {
    background: #FFFFFF;
    font-size: 140%;

    cursor: pointer;
}

.dtpicker-components .dtpicker-compValue {
    margin: 0.4em 0;
    width: 100%;
    border: none;
    background: #FFFFFF;

    font-size: 100%;

    -webkit-appearance: none;
    -moz-appearance: none;
}

.dtpicker-overlay .dtpicker-compValue:focus {
    outline: none;
    background: #F2FCFF;
}

.dtpicker-buttonCont {
    overflow: hidden;
    margin: 0.2em 1em;
}

.dtpicker-buttonCont .dtpicker-button {
    display: block;
    padding: 0.6em 0;
    width: 47%;
    background: #FF3B30;
    color: #FFFFFF;
    text-align: center;
    font-size: 1.3em;

    cursor: pointer;
}

.dtpicker-buttonCont .dtpicker-button:hover {
    color: #FFFFFF;
}

.dtpicker-singleButton .dtpicker-button {
    margin: 0.2em auto;
}

.dtpicker-twoButtons .dtpicker-buttonSet {
    float: left;
}

.dtpicker-twoButtons .dtpicker-buttonClear {
    float: right;
}