
SEND_FROM_MANAGER_EMAIL = True
VALID_MANAGER_EMAIL_DOMAINS = [
    'stusta.de', 'stustanet.de', 'stusta.mhn.de', 'stusta.net', 'stusta.sexy', 'stusta.party', 'stusta.io'
]

# Base URL for template links (without 'https://')
URL = 'vote.stustanet.de'
