{% load static %}
<!DOCTYPE html>
<html lang="de">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link rel="apple-touch-icon" sizes="180x180" href="{% static 'img/apple-touch-icon.png' %}">
  <link rel="icon" type="image/png" href="{% static 'img/favicon16.png' %}" sizes="16x16"/>
  <link rel="icon" type="image/png" href="{% static 'img/favicon32.png' %}" sizes="32x32"/>
  <link rel="icon" type="image/png" href="{% static 'img/favicon64.png' %}" sizes="64x64"/>
  <link rel="icon" type="image/png" href="{% static 'img/favicon128.png' %}" sizes="128x128"/>
  <link rel="stylesheet" href="{% static "bootstrap-4.5.3-dist/css/bootstrap.min.css" %}"/>
  <link rel="stylesheet" href="{% static "vote/css/style.css" %}"/>
  <link rel="stylesheet" href="{% static "management/css/style.css" %}"/>
  {% block head %}
  {% endblock %}
  <title>{% block title %}StuStaNet Wahlfang{% endblock %}</title>
</head>
<body>
<div id="content">
  <nav class="navbar navbar-expand navbar-dark bg-dark shadow">
    <div class="container-md">
      <a class="navbar-brand" href="{% url 'management:index' %}">
        <img src="{% static "img/logo_inv.png" %}" alt="StuStaNet">
      </a>
      <div class="navbar-text">Wahlfang</div>
      <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
              aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
        <span class="navbar-toggler-icon"></span>
      </button>
      <div class="collapse navbar-collapse" id="navbarNav">
        <ul class="navbar-nav ml-auto">
          <li class="nav-item">
            <a class="nav-link" href="{% url 'management:help' %}">Help</a>
          </li>
          {% if user.is_authenticated %}
            <li class="nav-item">
              <a class="nav-link" href="{% url 'management:logout' %}">Logout</a>
            </li>
          {% endif %}
        </ul>
      </div>
    </div>
  </nav>

  <div class="modal fade" id="alertModal" role="dialog">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h4 class="modal-title" id="alertModalTitle">Alert</h4>
          <button type="button" class="close" data-dismiss="modal">&times;</button>
        </div>
        <div class="modal-body" id="alertModalBody">
          <p>text</p>
        </div>
        <div class="modal-footer">
        </div>
      </div>
    </div>
  </div>

  <article class="container-md mb-4" role="main">
    <div class="row pt-3 justify-content-center">
      <div class="col-12">
        {% if messages %}
          <div class="messages">
            {% for message in messages %}
              <div
                  class="alert alert-dismissible fade show alert-{% if message.tags == 'error' %}danger{% else %}{{ message.tags }}{% endif %}"
                  role="alert">
                {{ message|escape }}
                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                  <span aria-hidden="true">&times;</span>
                </button>
              </div>
            {% endfor %}
          </div>
        {% endif %}
        <div class="messages">
          <div class="alert alert-dismissible fade show alert-success hide" role="alert" id="message-success">
            <div>some text</div>
            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
              <span aria-hidden="true">&times;</span>
            </button>
          </div>
        </div>
      </div>
    </div>
    {% block content_pre %}{% endblock %}
    {% block content %}
      No content here.
    {% endblock %}
  </article>

</div>
{% block footer_scripts %}
{% endblock %}
</body>
</html>
