# Generated by Django 3.1.2 on 2020-10-12 19:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('vote', '0015_auto_20201011_1826'),
    ]

    operations = [
        migrations.AddField(
            model_name='voter',
            name='name',
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
    ]
