# Generated by Django 3.0.5 on 2020-05-31 21:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0008_election_result_published'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='voter',
            name='remind_me',
        ),
    ]
