# Generated by Django 3.1.2 on 2020-11-03 18:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('vote', '0020_election_remind_text_sent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='session',
            name='start_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
