# Generated by Django 3.1.2 on 2020-10-11 16:26

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('vote', '0014_election_voters_self_apply'),
    ]

    operations = [
        migrations.AddField(
            model_name='application',
            name='voter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='application', to='vote.voter'),
        ),
        migrations.AlterUniqueTogether(
            name='application',
            unique_together={('voter', 'election')},
        ),
    ]
